#
# spec file for package ghc-unicode-collation
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pkg_name unicode-collation
%global pkgver %{pkg_name}-%{version}
%bcond_with tests
Name:           ghc-%{pkg_name}
Version:        0.1.3.6
Release:        2.5
Summary:        Haskell implementation of the Unicode Collation Algorithm
License:        BSD-2-Clause
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
Source1:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/revision/1.cabal#/%{pkg_name}.cabal
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-base-devel
BuildRequires:  ghc-base-prof
BuildRequires:  ghc-binary-devel
BuildRequires:  ghc-binary-prof
BuildRequires:  ghc-bytestring-devel
BuildRequires:  ghc-bytestring-prof
BuildRequires:  ghc-containers-devel
BuildRequires:  ghc-containers-prof
BuildRequires:  ghc-parsec-devel
BuildRequires:  ghc-parsec-prof
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-template-haskell-devel
BuildRequires:  ghc-template-haskell-prof
BuildRequires:  ghc-text-devel
BuildRequires:  ghc-text-prof
BuildRequires:  ghc-th-lift-instances-devel
BuildRequires:  ghc-th-lift-instances-prof
ExcludeArch:    %{ix86}
%if %{with tests}
BuildRequires:  ghc-tasty-devel
BuildRequires:  ghc-tasty-hunit-devel
BuildRequires:  ghc-tasty-hunit-prof
BuildRequires:  ghc-tasty-prof
BuildRequires:  ghc-tasty-quickcheck-devel
BuildRequires:  ghc-tasty-quickcheck-prof
BuildRequires:  ghc-unicode-transforms-devel
BuildRequires:  ghc-unicode-transforms-prof
%endif

%description
This library provides a pure Haskell implementation of the Unicode Collation
Algorithm described at <http://www.unicode.org/reports/tr10/>. It is not as
fully-featured or as performant as 'text-icu', but it avoids a dependency on a
large C library. Locale-specific tailorings are also provided.

%package devel
Summary:        Haskell %{pkg_name} library development files
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development
files.

%package -n ghc-%{pkg_name}-doc
Summary:        Haskell %{pkg_name} library documentation
Requires:       ghc-filesystem
BuildArch:      noarch

%description -n ghc-%{pkg_name}-doc
This package provides the Haskell %{pkg_name} library documentation.

%package -n ghc-%{pkg_name}-prof
Summary:        Haskell %{pkg_name} profiling library
Requires:       ghc-%{pkg_name}-devel = %{version}-%{release}
Supplements:    (ghc-%{pkg_name}-devel and ghc-prof)

%description -n ghc-%{pkg_name}-prof
This package provides the Haskell %{pkg_name} profiling library.

%prep
%autosetup -n %{pkg_name}-%{version}
cp -p %{SOURCE1} %{pkg_name}.cabal

%build
%ghc_lib_build

%install
%ghc_lib_install

%check
%cabal_test

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license LICENSE

%files devel -f %{name}-devel.files
%doc CHANGELOG.md README.md

%files -n ghc-%{pkg_name}-doc -f ghc-%{pkg_name}-doc.files
%license LICENSE

%files -n ghc-%{pkg_name}-prof -f ghc-%{pkg_name}-prof.files

%changelog
* Tue Jun 18 2024 Peter Simons <psimons@suse.com>
- Update unicode-collation to version 0.1.3.6 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Wed Dec 20 2023 Peter Simons <psimons@suse.com>
- Update unicode-collation to version 0.1.3.6.
  Upstream has edited the change log file since the last release in
  a non-trivial way, i.e. they did more than just add a new entry
  at the top. You can review the file at:
  http://hackage.haskell.org/package/unicode-collation-0.1.3.6/src/CHANGELOG.md
* Thu Aug 31 2023 Peter Simons <psimons@suse.com>
- Update unicode-collation to version 0.1.3.5.
  [#]# 0.1.3.5
    + Allow text 2.1.
* Thu Mar 30 2023 Peter Simons <psimons@suse.com>
- Updated spec file to conform with ghc-rpm-macros-2.5.2.
* Thu Mar 16 2023 Peter Simons <psimons@suse.com>
- Update unicode-collation to version 0.1.3.4.
  [#]# 0.1.3.4
    + Allow base 4.18.
* Mon Oct  3 2022 Peter Simons <psimons@suse.com>
- Update unicode-collation to version 0.1.3.3.
  [#]# 0.1.3.3
    + Allow base 4.17.  Closes #12.
* Thu May 19 2022 Peter Simons <psimons@suse.com>
- Update unicode-collation to version 0.1.3.2.
  [#]# 0.1.3.2
  * Allow text 2.0.
* Mon Nov 15 2021 psimons@suse.com
- Update unicode-collation to version 0.1.3.1.
  [#]# 0.1.3.1
  * Allow base 4.16 (so the library can compile with ghc 9.2).
  * Micro-optimization in normalize; update benchmarks.
* Thu May 13 2021 psimons@suse.com
- Add unicode-collation at version 0.1.3.
